@@ -58,8 +58,8 @@ API Reference
 #include "sqlite3.h"
 #endif
 
-#if SQLITE_VERSION_NUMBER < 3008002
-#error Your SQLite version is too old.  It must be at least 3.8.2
+#if SQLITE_VERSION_NUMBER < 3008005
+#error Your SQLite version is too old.  It must be at least 3.8.5
 #endif
 
 /* system headers */
@@ -1424,6 +1424,7 @@ modules etc. For example::
       ADDINT(SQLITE_DROP_VTABLE),
       ADDINT(SQLITE_FUNCTION),
       ADDINT(SQLITE_SAVEPOINT),
+      ADDINT(SQLITE_RECURSIVE),
       END,
 
       /* vtable best index constraints */
@@ -1489,6 +1490,7 @@ modules etc. For example::
       ADDINT(SQLITE_CANTOPEN_CONVPATH),
       ADDINT(SQLITE_IOERR_CONVPATH),
       ADDINT(SQLITE_CONSTRAINT_ROWID),
+      ADDINT(SQLITE_READONLY_DBMOVED),
       END,
 
       /* error codes */
@@ -1561,7 +1563,7 @@ modules etc. For example::
       ADDINT(SQLITE_LIMIT_LIKE_PATTERN_LENGTH),
       ADDINT(SQLITE_LIMIT_VARIABLE_NUMBER),
       ADDINT(SQLITE_LIMIT_TRIGGER_DEPTH),
-      /* We don't include the MAX limits - see https://code.google.com/p/apsw/issues/detail?id=17 */
+      /* We don't include the MAX limits - see https://github.com/rogerbinns/apsw/issues/17 */
       END,
 
       DICT("mapping_config"),
@@ -1651,6 +1653,7 @@ modules etc. For example::
       ADDINT(SQLITE_IOCAP_SEQUENTIAL),
       ADDINT(SQLITE_IOCAP_UNDELETABLE_WHEN_OPEN),
       ADDINT(SQLITE_IOCAP_POWERSAFE_OVERWRITE),
+      ADDINT(SQLITE_IOCAP_IMMUTABLE),
       END,
 
       DICT("mapping_sync"),
@@ -1684,6 +1687,10 @@ modules etc. For example::
       ADDINT(SQLITE_FCNTL_TEMPFILENAME),
       ADDINT(SQLITE_FCNTL_MMAP_SIZE),
       ADDINT(SQLITE_FCNTL_TRACE),
+      ADDINT(SQLITE_FCNTL_COMMIT_PHASETWO),
+      ADDINT(SQLITE_FCNTL_HAS_MOVED),
+      ADDINT(SQLITE_FCNTL_SYNC),
+      ADDINT(SQLITE_FCNTL_WIN32_SET_HANDLE),
       END
 
       };
